@@ -17,4 +17,8 @@ from .ratios import financial_statement_growth
 
 from .stock_data import stock_data
 from .stock_data import stock_data_detailed
-from .stock_data import stock_dividend
\ No newline at end of file
+from .stock_data import stock_dividend
+
+import ssl
+
+ssl._create_default_https_context = ssl._create_unverified_context
\ No newline at end of file
